@@ -3,7 +3,7 @@
 # Worksheet - A class for writing Excel Worksheets.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright 2013-2022, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 import re
 import datetime
@@ -635,10 +635,10 @@ def get_sparkline_style(style_id):
 
 def supported_datetime(dt):
     # Determine is an argument is a supported datetime object.
-    return(isinstance(dt, (datetime.datetime,
+    return isinstance(dt, (datetime.datetime,
                            datetime.date,
                            datetime.time,
-                           datetime.timedelta)))
+                           datetime.timedelta))
 
 
 def remove_datetime_timezone(dt_obj, remove_timezone):
